NodApsFlag class

Constructors

NodApsFlag(int value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
finalinherited

Methods

create(int value) NodApsFlag
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator &(dynamic other) NodApsFlag
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator |(dynamic other) NodApsFlag
inherited

Constants

SE_NODBIT_FOPOINT → const NodApsFlag
focal point of orbit instead of aphelion
SE_NODBIT_MEAN → const NodApsFlag
mean nodes/apsides
SE_NODBIT_OSCU → const NodApsFlag
osculating nodes/apsides
SE_NODBIT_OSCU_BAR → const NodApsFlag
same, but motion about solar system barycenter is considered