SwephFlag class
Flag bits for flag parameter in various methods The flag bits are defined in such a way that iflag = 0 delivers what one usually wants:
- the default ephemeris (SWISS EPHEMERIS) is used,
- apparent geocentric positions referring to the true equinox of date are returned. If not only coordinates, but also speed values are required, use flag = SEFLG_SPEED.
Properties
Methods
-
create(
int value) → SwephFlag -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator &(
dynamic other) → SwephFlag -
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator |(
dynamic other) → SwephFlag -
inherited
Static Properties
- SEFLG_ASTROMETRIC → SwephFlag
-
astrometric position, i.e. with light-time, but without aberration and light deflection
final
- SEFLG_TEST_PLMOON → SwephFlag
-
test raw data in files sepm9*
final
Constants
- SEFLG_BARYCTR → const SwephFlag
- barycentric position
- SEFLG_CENTER_BODY → const SwephFlag
- calculate position of center of body (COB) of planet, not barycenter of its system
- SEFLG_DPSIDEPS_1980 → const SwephFlag
- reproduce JPL Horizons 1962 - today to 0.002 arcsec.
- SEFLG_EQUATORIAL → const SwephFlag
- equatorial positions are wanted
- SEFLG_HELCTR → const SwephFlag
- heliocentric position
- SEFLG_ICRS → const SwephFlag
- ICRS (DE406 reference frame;
- SEFLG_J2000 → const SwephFlag
- no precession, i.e. give J2000 equinox
- SEFLG_JPLEPH → const SwephFlag
- use JPL ephemeris
- SEFLG_JPLHOR → const SwephFlag
- SEFLG_JPLHOR_APPROX → const SwephFlag
- approximate JPL Horizons 1962 - today
- SEFLG_MOSEPH → const SwephFlag
- use Moshier ephemeris
- SEFLG_NOABERR → const SwephFlag
- turn off 'annual' aberration of light
- SEFLG_NOGDEFL → const SwephFlag
- turn off gravitational deflection
- SEFLG_NONUT → const SwephFlag
- no nutation, i.e. mean equinox of date
- SEFLG_ORBEL_AA → const SwephFlag
- used for Astronomical Almanac mode in calculation of Kepler elipses
- SEFLG_RADIANS → const SwephFlag
- coordinates in radians, not degrees
- SEFLG_SIDEREAL → const SwephFlag
- sidereal position
- SEFLG_SPEED → const SwephFlag
- high precision speed
- SEFLG_SPEED3 → const SwephFlag
- speed from 3 positions (do not use it, SEFLG_SPEED is faster and more precise.)
- SEFLG_SWIEPH → const SwephFlag
- use SWISSEPH ephemeris
- SEFLG_TOPOCTR → const SwephFlag
- topocentric position
- SEFLG_TROPICAL → const SwephFlag
- tropical position (default;
- SEFLG_TRUEPOS → const SwephFlag
- true/geometric position, not apparent position
- SEFLG_XYZ → const SwephFlag
- cartesian, not polar, coordinates